@@ -3,9 +3,9 @@
 package BorderStyle;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-01-24'; # DATE
+our $DATE = '2022-01-26'; # DATE
 our $DIST = 'BorderStyle'; # DIST
-our $VERSION = '2.0.7'; # VERSION
+our $VERSION = '2.0.8'; # VERSION
 
 1;
 # ABSTRACT: Border styles
@@ -26,7 +26,7 @@ BorderStyle - Border styles
 
 =head1 VERSION
 
-This document describes version 2.0.7 of BorderStyle (from Perl distribution BorderStyle), released on 2022-01-24.
+This document describes version 2.0.8 of BorderStyle (from Perl distribution BorderStyle), released on 2022-01-26.
 
 =head1 DESCRIPTION
 
@@ -146,7 +146,7 @@ An array. Required. Format for the characters in C<chars>:
  #x 0  1  2  3  4  5  6  7
    [A, B, C, D],             # 0 Top border characters (if drawing header rows)
    [E, F, G],                # 1 Vertical separators for header row
-   [H, I, J, K, a, b],       # 2 Separator between header row and first data row
+   [H, I, J, K, a, b, c, d], # 2 Separator between header row and first data row
    [L, M, N],                # 3 Vertical separators for data row
    [O, P, Q, R, e, f, g, h], # 4 Separator between data rows
    [S, T, U, V],             # 5 Bottom border characters
@@ -213,12 +213,23 @@ C<f>, C<g>, C<h>):
  L       M       N    |
  STTTTTTTUTTTTTTTV    v
 
+In the case of a header-data separator line also having been cut by a multirow
+cell (note the C<c> and C<d> border character):
+
+ ABBBBBBBBBCBBBBBBBBBBBBBBBBBBBBBCBBBBBBBBBD
+ F header1 F       header2       F header3 G
+ H         cIIIIIIIIIIaIIIIIIIIIId         J
+ L         M header2a M header2b F         N
+ OPPPPPPPPPQPPPPPPPPPPQPPPPPPPPPPQPPPPPPPPPR
+ M data1a  M data1b   M data1c   M data1d  N
+ STTTTTTTTTUTTTTTTTTTTUTTTTTTTTTTUTTTTTTTTTV
+
 A character can also be a coderef that will be called with C<< ($self, $y, $x,
 $n, \%args) >>. See L</Border style character>.
 
 =back
 
-=head1 Border style character
+=head2 Border style character
 
 A border style character can be a single-character string, or a coderef to allow
 border style that is context-sensitive.
